@@ -275,6 +275,8 @@ struct CropWidgetPrivate : public QWidget
 
         QObject::connect(dialogButtonBox, &QDialogButtonBox::accepted, q, &CropWidget::cropRequested);
         QObject::connect(dialogButtonBox, &QDialogButtonBox::rejected, q, &CropWidget::done);
+        QPushButton *resetButton = dialogButtonBox->button(QDialogButtonBox::Reset);
+        connect(resetButton, &QPushButton::clicked, q, &CropWidget::reset);
     }
 
     QWidget* boxWidget(QWidget* parent = nullptr)
@@ -368,7 +370,7 @@ struct CropWidgetPrivate : public QWidget
 
         // (6) Dialog buttons
         box = boxWidget(cropWidget);
-        dialogButtonBox = new QDialogButtonBox(QDialogButtonBox::Cancel | QDialogButtonBox::Ok, box);
+        dialogButtonBox = new QDialogButtonBox(QDialogButtonBox::Cancel | QDialogButtonBox::Reset | QDialogButtonBox::Ok, box);
         box->layout()->addWidget(dialogButtonBox);
         flowLayout->addWidget(box);
     }
@@ -453,6 +455,19 @@ QSizeF CropWidget::cropRatio() const
     return d->chosenRatio();
 }
 
+void CropWidget::reset()
+{
+    d->ratioComboBox->clearEditText();
+    d->ratioComboBox->setCurrentIndex(-1);
+
+    QSize size = d->mDocument->size();
+    d->leftSpinBox->setValue(0);
+    d->widthSpinBox->setValue(size.width());
+    d->topSpinBox->setValue(0);
+    d->heightSpinBox->setValue(size.height());
+    emit rectReset();
+}
+
 void CropWidget::setCropRatioIndex(int index)
 {
     d->ratioComboBox->setCurrentIndex(index);
@@ -528,7 +543,7 @@ void CropWidget::applyRatioConstraint()
 
 void CropWidget::slotAdvancedCheckBoxToggled(bool checked)
 {
-    for (auto w : d->mAdvancedWidgets) {
+    for (auto w : qAsConst(d->mAdvancedWidgets)) {
         w->setVisible(checked);
     }
     d->mPreserveAspectRatioWidget->setVisible(!checked);
