@@ -113,7 +113,7 @@ QString ThumbnailProvider::thumbnailBaseDir(ThumbnailGroup::Enum group)
         break;
     case ThumbnailGroup::Large2x:
     default:
-        dir += "x-gwenview/"; // Should never be hit, but just in case
+        dir += QLatin1String("x-gwenview/"); // Should never be hit, but just in case
     }
     return dir;
 }
@@ -175,11 +175,10 @@ ThumbnailProvider::ThumbnailProvider()
 ThumbnailProvider::~ThumbnailProvider()
 {
     LOG(this);
-    abortSubjob();
-    mThumbnailGenerator->cancel();
     disconnect(mThumbnailGenerator, nullptr, this, nullptr);
     disconnect(mThumbnailGenerator, nullptr, sThumbnailWriter, nullptr);
-    connect(mThumbnailGenerator, SIGNAL(finished()), mThumbnailGenerator, SLOT(deleteLater()));
+    abortSubjob();
+    mThumbnailGenerator->cancel();
     if (mPreviousThumbnailGenerator) {
         disconnect(mPreviousThumbnailGenerator, nullptr, sThumbnailWriter, nullptr);
     }
@@ -194,7 +193,7 @@ void ThumbnailProvider::stop()
     // startCreatingThumbnail() will take care that these two threads won't work on the same item.
     mItems.clear();
     abortSubjob();
-    if (mThumbnailGenerator->isRunning() && !mPreviousThumbnailGenerator) {
+    if (!mThumbnailGenerator->isStopped() && !mPreviousThumbnailGenerator) {
         mPreviousThumbnailGenerator = mThumbnailGenerator;
         mPreviousThumbnailGenerator->cancel();
         disconnect(mPreviousThumbnailGenerator, nullptr, this, nullptr);
@@ -525,7 +524,7 @@ void ThumbnailProvider::startCreatingThumbnail(const QString& pixPath)
     // connect mPreviousThumbnailGenerator's signal "finished" to determineNextIcon
     // which will load the thumbnail from sThumbnailWriter or from disk
     // (because we re-add mCurrentItem to mItems).
-    if (mPreviousThumbnailGenerator && mPreviousThumbnailGenerator->isRunning() &&
+    if (mPreviousThumbnailGenerator && !mPreviousThumbnailGenerator->isStopped() &&
         mOriginalUri == mPreviousThumbnailGenerator->originalUri() &&
         mOriginalTime == mPreviousThumbnailGenerator->originalTime() &&
         mOriginalFileSize == mPreviousThumbnailGenerator->originalFileSize() &&
